==> dhcp-agent-0.40.tar.gz: dhcp-agent-0.40/src/dhcp-conf.h <==

/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-conf.h,v 1.3 2002/12/16 07:20:42 actmodern Exp $
 *
 * Copyright 2002 Thamer Alharbash
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef DHCP_CONF_H
#define DHCP_CONF_H

/* typedef of configuration drivers. */
typedef void *(*argument_compiler_t)(conf_t *conf, const char **argument_strings, const arg_symbol_t *argument_symbols);
typedef void (*argument_destroy_t)(void *);

/* conf return types. */
enum conf_return_types { CONF_OK = 0, CONF_ERROR };

/* conf argument types -- these index the argument drivers. */
enum conf_argument_type { CONF_IDENTIFIER = 0, CONF_ADDRESS,
                          CONF_ASSIGNMENT, CONF_BOOLEAN, CONF_STRING, CONF_STRING_LIST, 
                          CONF_GROUP };
#endif /* DHCP_CONF_H */

==> dhcp-agent-0.41.tar.gz: dhcp-agent-0.41/src/dhcp-conf.h <==

/* $Header: /cvsroot/dhcp-agent/dhcp-agent/src/dhcp-conf.h,v 1.4 2003/07/12 17:42:36 actmodern Exp $
 *
 * Copyright 2002 Thamer Alharbash
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in
 * the documentation and/or other materials provided with the
 * distribution.
 * 3. The names of the authors may not be used to endorse or promote
 * products derived from this software without specific prior
 * written permission.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef DHCP_CONF_H
#define DHCP_CONF_H

/* typedef of configuration drivers. */
typedef void *(*argument_compiler_t)(conf_t *conf, const char **argument_strings, const arg_symbol_t *argument_symbols);
typedef void (*argument_destroy_t)(void *);

/* conf return types. */
enum conf_return_types { CONF_OK = 0, CONF_ERROR };

/* conf argument types -- these index the argument drivers. */
enum conf_argument_type { CONF_IDENTIFIER = 0, CONF_ADDRESS, CONF_MAC_ADDRESS,
                          CONF_ASSIGNMENT, CONF_BOOLEAN, CONF_STRING, CONF_STRING_LIST, 
                          CONF_GROUP };
#endif /* DHCP_CONF_H */
